@@ -1,23 +1,10 @@
 from __future__ import absolute_import
 
-import os
-import sys
 import time
-import warnings
 from collections import OrderedDict
 
 from pyaedt import pyaedt_function_handler
-
-try:
-    import clr
-
-    clr.AddReference("System.Collections")
-    from System.Collections.Generic import List
-except ImportError:  # pragma: no cover
-    if os.name != "posix":
-        warnings.warn("PythonNET is needed to run PyAEDT.")
-    elif sys.version[0] == 3 and sys.version[1] < 7:
-        warnings.warn("EDB requires Linux Python 3.7 or later.")
+from pyaedt.generic.clr_module import List
 
 
 class EDBLayer(object):
