@@ -159,8 +159,8 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
         """Primitives.
 
         .. deprecated:: 0.4.15
-        There is no need to use primitives anymore. You can instantiate methods for
-        primitives directly from the modeler.
+            There is no need to use the ``primitives`` property anymore. You can instantiate
+            methods for primitives directly from the modeler.
 
         Returns
         -------
@@ -666,6 +666,38 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
         self._init_prims()
         return True
 
+    @pyaedt_function_handler()
+    def duplicate_across_layers(self, objects, layers):
+        """Duplicate one or more elements along a vector.
+
+        Parameters
+        ----------
+        objects : list
+            List of elements to duplicate.
+        layers : str, list
+            Layer name on which duplicate object.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.DuplicateAcrossLyrs
+        """
+        if isinstance(objects, str):
+            objects = [objects]
+        if isinstance(layers, str):
+            layers = [layers]
+        varg1 = ["NAME:elements"] + objects
+        varg2 = ["NAME:layers"] + layers
+
+        self.oeditor.DuplicateAcrossLyrs(varg1, varg2)
+        self._init_prims()
+        return True
+
     @pyaedt_function_handler()
     def set_temperature_dependence(
         self,
