@@ -6,13 +6,13 @@ objects (points, lines, sheeets, and solids) within the AEDT 3D Layout Modeler.
 """
 from __future__ import absolute_import  # noreorder
 
+import math
 import re
 
 from pyaedt import _retry_ntimes
 from pyaedt import pyaedt_function_handler
+from pyaedt.generic.constants import unit_converter
 from pyaedt.modeler.GeometryOperators import GeometryOperators
-from pyaedt.modeler.Object3d import clamp
-from pyaedt.modeler.Object3d import rgb_color_codes
 
 
 class Objec3DLayout(object):
@@ -121,6 +121,40 @@ class Objec3DLayout(object):
             vMaterial = ["NAME:Angle", "Value:=", value]
             self.change_property(vMaterial)
 
+    @property
+    def absolute_angle(self):
+        """Get the absolute angle location for 2 pins components.
+
+        Returns
+        -------
+        float
+        """
+        if self.prim_type != "component":
+            return 0.0
+        comp_pins = self.m_Editor.GetComponentPins(self.name)
+        if len(comp_pins) == 2:
+            pin_1_name = comp_pins[0]
+            pin_2_name = comp_pins[1]
+            pin1_info = self.m_Editor.GetComponentPinInfo(self.name, pin_1_name)
+            pin2_info = self.m_Editor.GetComponentPinInfo(self.name, pin_2_name)
+            pin1_x = pin1_info[1].split("=")[1]
+            pin1_y = pin1_info[2].split("=")[1]
+            pin2_x = pin2_info[1].split("=")[1]
+            pin2_y = pin2_info[2].split("=")[1]
+            p1x = float(pin1_x)
+            p1y = float(pin1_y)
+            p2x = float(pin2_x)
+            p2y = float(pin2_y)
+            dy = float(p2y - p1y)
+            dx = float(p2x - p1x)
+            angle_deg = math.atan2(dy, dx) * 180.0 / math.pi
+            if abs(angle_deg - 90.0) < 1:
+                angle_deg = 90.0
+            if abs(angle_deg) < 1:
+                angle_deg = 0.0
+            return angle_deg
+        return 0.0
+
     @property
     def net_name(self):
         """Get/Set the net name.
@@ -167,9 +201,77 @@ class Objec3DLayout(object):
             vMaterial = ["NAME:PlacementLayer", "Value:=", layer_name]
             self.change_property(vMaterial)
 
+    @property
+    def bounding_box(self):
+        """Get component bounding box.
+
+        Returns
+        -------
+        list
+            [BB_lower_left_X, BB_lower_left_Y, BB_upper_right_X, BB_upper_right_Y].
+        """
+        info = self.m_Editor.GetComponentInfo(self.name)
+        bbllx = bblly = bburx = bbury = 0
+        for i in info:
+            if "BBoxLLx" in i:
+                bbllx = float(i.split("=")[1])
+            elif "BBoxLLy" in i:
+                bblly = float(i.split("=")[1])
+            elif "BBoxURx" in i:
+                bburx = float(i.split("=")[1])
+            elif "BBoxURy" in i:
+                bbury = float(i.split("=")[1])
+        bbllx = round(unit_converter(bbllx, output_units=self._primitives.model_units), 9)
+        bblly = round(unit_converter(bblly, output_units=self._primitives.model_units), 9)
+        bburx = round(unit_converter(bburx, output_units=self._primitives.model_units), 9)
+        bbury = round(unit_converter(bbury, output_units=self._primitives.model_units), 9)
+        return [bbllx, bblly, bburx, bbury]
+
+    @pyaedt_function_handler()
+    def create_clearance_on_component(self, extra_soldermask_clearance=5e-3):
+        """Create a Clearance on Soldermask layer by drawing a rectangle.
+
+        Parameters
+        ----------
+        extra_soldermask_clearance : float, optional
+            Extra Soldermask value in model units to be applied on component bounding box.
+        Returns
+        -------
+            bool
+        """
+        if self.prim_type != "component":
+            self._primitives.logger.error("Clearance applies only to components.")
+            return False
+        bbox = self.bounding_box
+        start_points = [bbox[0] - extra_soldermask_clearance, bbox[1] - extra_soldermask_clearance]
+
+        dims = [bbox[2] - bbox[0] + 2 * extra_soldermask_clearance, bbox[3] - bbox[1] + 2 * extra_soldermask_clearance]
+        drawings = []
+        if self.placement_layer == self._primitives.layers.all_signal_layers[0].name:
+            for lay in self._primitives.layers.stackup_layers:
+                if lay.name != self.placement_layer:
+                    drawings.append(lay.name)
+                else:
+                    break
+        else:
+            for lay in reversed(self._primitives.layers.stackup_layers):
+                if lay.name != self.placement_layer:
+                    drawings.append(lay.name)
+                else:
+                    break
+        for layername in drawings:
+            rect = self._primitives.create_rectangle(
+                layername,
+                [self._primitives.arg_with_dim(start_points[0]), self._primitives.arg_with_dim(start_points[1])],
+                [self._primitives.arg_with_dim(dims[0]), self._primitives.arg_with_dim(dims[1])],
+            )
+            self._primitives.rectangles[rect].negative = True
+        return True
+
     @property
     def location(self):
-        """Retrieve/Set the component location.
+        """Retrieve/Set the absolute location in model units.
+        Location is computed with combination of 3d Layout location and model center.
 
         Returns
         -------
@@ -181,7 +283,24 @@ class Objec3DLayout(object):
 
         >>> oEditor.GetPropertyValue
         """
-        if self.prim_type in ["component", "pin", "via"]:
+        if self.prim_type == "component":
+            info = self.m_Editor.GetComponentInfo(self.name)
+            bbllx = bblly = bburx = bbury = 0
+            for i in info:
+                if "BBoxLLx" in i:
+                    bbllx = float(i.split("=")[1])
+                elif "BBoxLLy" in i:
+                    bblly = float(i.split("=")[1])
+                elif "BBoxURx" in i:
+                    bburx = float(i.split("=")[1])
+                elif "BBoxURy" in i:
+                    bbury = float(i.split("=")[1])
+            loc_x = (bburx + bbllx) / 2
+            loc_y = (bbury + bblly) / 2
+            loc_x = round(unit_converter(loc_x, output_units=self._primitives.model_units), 9)
+            loc_y = round(unit_converter(loc_y, output_units=self._primitives.model_units), 9)
+            return [loc_x, loc_y]
+        elif self.prim_type in ["pin", "via"]:
             location = _retry_ntimes(
                 self._n, self.m_Editor.GetPropertyValue, "BaseElementTab", self.name, "Location"
             ).split(",")
@@ -197,8 +316,28 @@ class Objec3DLayout(object):
 
     @location.setter
     def location(self, position):
+        if self.prim_type == "component":
+            info = self.m_Editor.GetComponentInfo(self.name)
+            bbllx = bblly = bburx = bbury = 0
+            for i in info:
+                if "BBoxLLx" in i:
+                    bbllx = float(i.split("=")[1])
+                elif "BBoxLLy" in i:
+                    bblly = float(i.split("=")[1])
+                elif "BBoxURx" in i:
+                    bburx = float(i.split("=")[1])
+                elif "BBoxURy" in i:
+                    bbury = float(i.split("=")[1])
+            position[0] -= unit_converter((bburx + bbllx) / 2, output_units=self._primitives.model_units)
+            position[1] -= unit_converter((bbury + bblly) / 2, output_units=self._primitives.model_units)
         if self.prim_type in ["component", "pin", "via"]:
-            props = ["NAME:Location", "X:=", str(position[0]), "Y:=", str(position[0])]
+            props = [
+                "NAME:Location",
+                "X:=",
+                self._primitives.arg_with_dim(position[0]),
+                "Y:=",
+                self._primitives.arg_with_dim(position[1]),
+            ]
             self.change_property(props)
 
     @property
@@ -326,8 +465,8 @@ class Components3DLayout(Objec3DLayout, object):
             return parts[self.part_type]
         return -1
 
-    @pyaedt_function_handler
-    def enabled(self, status=True):
+    @property
+    def enabled(self):
         """Enable or Disable the RLC Component.
 
         Parameters
@@ -340,13 +479,19 @@ class Components3DLayout(Objec3DLayout, object):
         bool
             `True` if succeeded.
         """
+        comp_info = self.m_Editor.GetComponentInfo(self.name)
+        for el in comp_info:
+            if "ComponentProp=" in el and "CompPropEnabled=false" in el:
+                return False
+            elif "ComponentProp=" in el and "CompPropEnabled=true" in el:
+                return True
+        return True
+
+    @enabled.setter
+    def enabled(self, status):
         if self._part_type_id in [0, 4, 5]:
             return False
-        args = [
-            "NAME:Model Info",
-            ["NAME:Model", "RLCProp:=", ["CompPropEnabled:=", status], "CompType:=", self._part_type_id],
-        ]
-        return self.change_property(args)
+        self.m_Editor.EnableComponents(["NAME:Components", self.name], status)
 
     @property
     def solderball_enabled(self):
@@ -508,7 +653,7 @@ class Components3DLayout(Objec3DLayout, object):
                 if "PortProp(" in p:
                     model = p
                     break
-            s = r".+PortProp\(rh='(.+?)', rsa=(.+?), rsx='(.+?)', rsy='(.+?)'"
+            s = r".+PortProp\(rh='(.+?)', rsa=(.+?), rsx='(.+?)', rsy='(.+?)'\)"
             m = re.search(s, model)
             rh = "0"
             rsx = "0"
@@ -520,6 +665,18 @@ class Components3DLayout(Objec3DLayout, object):
                 rsy = m.group(4)
                 if m.group(2) == "false":
                     rsa = False
+            s = r".+DieProp\(dt=(.+?), do=(.+?), dh='(.+?)', lid=(.+?)\)"
+            m = re.search(s, model)
+            dt = 0
+            do = 0
+            dh = "0"
+            lid = -100
+            if m:
+                dt = int(m.group(1))
+                do = int(m.group(2))
+                dh = str(m.group(3))
+                lid = int(m.group(4))
+
             args = [
                 "NAME:Model Info",
                 [
@@ -539,6 +696,8 @@ class Components3DLayout(Objec3DLayout, object):
                             "sbn:=",
                             material,
                         ],
+                        "DieProp:=",
+                        ["dt:=", dt, "do:=", do, "dh:=", dh, "lid:=", lid],
                         "PortProp:=",
                         ["rh:=", rh, "rsa:=", rsa, "rsx:=", rsx, "rsy:=", rsy],
                     ],
@@ -663,7 +822,7 @@ class Pins3DLayout(Objec3DLayout, object):
         """Retrieve the hole diameter of the pin.
 
         Returns
-        --------
+        -------
         float
            Hole diameter of the pin.
 
@@ -1317,208 +1476,6 @@ class Points3dLayout(object):
             return True
 
 
-class Point(object):
-    """Manages point attributes for the AEDT 3D Modeler.
-
-    Parameters
-    ----------
-    primitives : :class:`pyaedt.modeler.Primitives3D.Primitives3D`
-        Inherited parent object.
-    name : str
-        Name of the point.
-
-    Examples
-    --------
-    Basic usage demonstrated with an HFSS design:
-
-    >>> from pyaedt import Hfss
-    >>> aedtapp = Hfss()
-    >>> primitives = aedtapp.modeler
-
-    Create a point, to return an :class:`pyaedt.modeler.Object3d.Point`.
-
-    >>> point = primitives.create_point([30, 30, 0], "my_point", (0, 195, 255))
-    >>> my_point = primitives.points_by_name[point.name]
-    """
-
-    def __init__(self, primitives, name):
-        self._name = name
-        self._point_coordinate_system = "Global"
-        self._color = None
-        self._position = None
-        self._primitives = primitives
-        self._all_props = None
-
-    @property
-    def m_Editor(self):
-        """Pointer to the oEditor object in the AEDT API. This property is
-        intended primarily for use by FacePrimitive, EdgePrimitive, and
-        VertexPrimitive child objects.
-
-        Returns
-        -------
-        oEditor COM Object
-
-        """
-        return self._primitives.oeditor
-
-    @property
-    def logger(self):
-        """Logger."""
-        return self._primitives.logger
-
-    @property
-    def name(self):
-        """Name of the point as a string value.
-
-        Returns
-        -------
-        str
-           Name of object as a string value.
-
-        References
-        ----------
-
-        >>> oEditor.GetPropertyValue
-        >>> oEditor.ChangeProperty
-
-        """
-        return self._name
-
-    @name.setter
-    def name(self, point_name):
-        if point_name not in self._primitives.points_by_name.keys:
-            if point_name != self._name:
-                name_property = []
-                name_property.append("NAME:Name")
-                name_property.append("Value:=")
-                name_property.append(point_name)
-                changed_property = ["NAME:ChangedProps", name_property]
-                property_servers = ["NAME:PropServers"]
-                property_servers.append(self._name)
-                point_tab = ["NAME:Geometry3DPointTab", property_servers, changed_property]
-                all_tabs = ["NAME:AllTabs", point_tab]
-                _retry_ntimes(10, self._primitives.oeditor.ChangeProperty, all_tabs)
-                self._name = point_name
-                self._primitives.cleanup_objects()
-        else:
-            self.logger.warning("A point named '%s' already exists.", point_name)
-
-    @property
-    def valid_properties(self):
-        """Valid properties.
-
-        References
-        ----------
-
-        >>> oEditor.GetProperties
-        """
-        if not self._all_props:
-            self._all_props = _retry_ntimes(10, self.m_Editor.GetProperties, "Geometry3DPointTab", self._name)
-        return self._all_props
-
-    # Note: We currently cannot get the color property value because
-    # when we try to access it, we only get access to the 'edit' button.
-    # Following is the line that we would use but it currently returns 'edit'.
-    # color = _retry_ntimes(10, self.m_Editor.GetPropertyValue, "Geometry3DPointTab", self._name, "Color")
-    def set_color(self, color_value):
-        """Set symbol color.
-
-        Parameters
-        ----------
-        color_value : string
-            String exposing the new color of the point in the format of "(001 255 255)".
-
-        References
-        ----------
-
-        >>> oEditor.ChangeProperty
-
-        Examples
-        --------
-        >>> point = self.aedtapp.modeler.create_point([30, 30, 0], "demo_point")
-        >>> point.set_color("(143 175 158)")
-
-        """
-        color_tuple = None
-        if isinstance(color_value, str):
-            try:
-                color_tuple = rgb_color_codes[color_value]
-            except KeyError:
-                parse_string = color_value.replace(")", "").replace("(", "").split()
-                if len(parse_string) == 3:
-                    color_tuple = tuple([int(x) for x in parse_string])
-        else:
-            try:
-                color_tuple = tuple([int(x) for x in color_value])
-            except ValueError:
-                pass
-
-        if color_tuple:
-            try:
-                R = clamp(color_tuple[0], 0, 255)
-                G = clamp(color_tuple[1], 0, 255)
-                B = clamp(color_tuple[2], 0, 255)
-                vColor = ["NAME:Color", "R:=", str(R), "G:=", str(G), "B:=", str(B)]
-                self._change_property(vColor)
-                self._color = (R, G, B)
-            except TypeError:
-                color_tuple = None
-        else:
-            msg_text = "Invalid color input {} for object {}.".format(color_value, self._name)
-            self._primitives.logger.warning(msg_text)
-
-    @property
-    def coordinate_system(self):
-        """Coordinate system of the point.
-
-        Returns
-        -------
-        str
-            Name of the point's coordinate system.
-
-        References
-        ----------
-
-        >>> oEditor.GetPropertyValue
-        >>> oEditor.ChangeProperty
-
-        """
-        if self._point_coordinate_system is not None:
-            return self._point_coordinate_system
-        if "Orientation" in self.valid_properties:
-            self._point_coordinate_system = _retry_ntimes(
-                10, self.m_Editor.GetPropertyValue, "Geometry3DPointTab", self._name, "Orientation"
-            )
-            return self._point_coordinate_system
-
-    @coordinate_system.setter
-    def coordinate_system(self, new_coordinate_system):
-
-        coordinate_system = ["NAME:Orientation", "Value:=", new_coordinate_system]
-        self._change_property(coordinate_system)
-        self._point_coordinate_system = new_coordinate_system
-        return True
-
-    @pyaedt_function_handler()
-    def delete(self):
-        """Delete the point.
-
-        References
-        ----------
-
-        >>> oEditor.Delete
-        """
-        arg = ["NAME:Selections", "Selections:=", self._name]
-        self.m_Editor.Delete(arg)
-        self._primitives.remove_point(self.name)
-        self.__dict__ = {}
-
-    @pyaedt_function_handler()
-    def _change_property(self, vPropChange):
-        return self._primitives._change_point_property(vPropChange, self.name)
-
-
 class ComponentsSubCircuit3DLayout(Objec3DLayout, object):
     """Contains 3d Components in HFSS 3D Layout.
 
