@@ -10,4 +10,8 @@ if int(sys.argv[2]) == 1:
 else:
     val = False
 
-launch_server(ansysem_path=sys.argv[1], non_graphical=val, port=int(sys.argv[3]))
+if len(sys.argv)>4:
+   threaded = True if sys.argv[4]==1 else False
+else:
+   threaded = True
+launch_server(ansysem_path=sys.argv[1], non_graphical=val, port=int(sys.argv[3]), threaded=threaded)
